@@ -46,6 +46,7 @@ THIRD_PARTY_APPS = (
     'crispy_forms',
     'compressor',
     'csp',
+    "corsheaders",
 )
 LOCAL_APPS = (
     'db.base',
@@ -67,6 +68,7 @@ INSTALLED_APPS = DJANGO_APPS + THIRD_PARTY_APPS + LOCAL_APPS
 # Middlware
 MIDDLEWARE = (
     'django.contrib.sessions.middleware.SessionMiddleware',
+    'corsheaders.middleware.CorsMiddleware',
     'django.middleware.common.CommonMiddleware',
     'django.middleware.csrf.CsrfViewMiddleware',
     'django.contrib.auth.middleware.AuthenticationMiddleware',
@@ -384,6 +386,9 @@ SPECTACULAR_SETTINGS = {
 # Security
 SECRET_KEY = config('SECRET_KEY', default='changeme')
 SECURE_HSTS_SECONDS = config('SECURE_HSTS_SECONDS', default=31536000, cast=int)
+CORS_ALLOW_ALL_ORIGINS = config('CORS_ALLOW_ALL_ORIGINS', default=True, cast=bool)
+CORS_URLS_REGEX = config('CORS_URLS_REGEX', default=r'^(?:/api/artifacts/.*|/media/artifacts/.*)$')
+CORS_ALLOW_METHODS = config('CORS_ALLOW_METHODS', default='GET, OPTIONS', cast=Csv())
 CSP_DEFAULT_SRC = config(
     'CSP_DEFAULT_SRC',
     cast=lambda v: tuple(s.strip() for s in v.split(',')),
